/* liblwevent/src/liblwevent/300_fdparams.c
 *
 *  (c)2007, Laurence Withers, <l@lwithers.me.uk>.
 *  Released under the GNU GPLv3. See file COPYING or
 *  http://www.gnu.org/copyleft/gpl.html for details.
*/



/* lwevent_get_*()
 *  Functions for retrieving attributes stored in a struct lwevent.
 */
int lwevent_get_fd(const struct lwevent* ev) 
{
    return ev->fd;
}

int lwevent_get_events(const struct lwevent* ev) 
{
    return ev->events;
}

lwevent_callback lwevent_get_callback(const struct lwevent* ev) 
{
    return ev->callback;
}

void* lwevent_get_user(const struct lwevent* ev) 
{
    return ev->user;
}

lwevent_dtor lwevent_get_dtor(const struct lwevent* ev) 
{
    return ev->dtor;
}

int lwevent_get_autodestroy(const struct lwevent* ev) 
{
    return ev->autodestroy;
}



/* lwevent_set_events()
 *  Calls epoll_ctl(EPOLL_CTL_MOD) to change the events associated with the object `ev'. Does not
 *  perform the call if the new events match the current events. Returns -1 if epoll_ctl fails.
 */
int lwevent_set_events(struct lwevent* ev, int events)
{
    struct epoll_event ee;

    /* don't call epoll_ctl() if no change */
    if(events == ev->events) return 0;

    /* try the modification */
    ee.events = events;
    ee.data.ptr = ev;
    if(TEMP_FAILURE_RETRY( epoll_ctl(lwevent_epoll_fd, EPOLL_CTL_MOD, ev->fd, &ee) )) {
        /* if we are deactivated, ENOENT will be returned, but we still want to store the events
         * for later, so they will be used when reactivation occurs. */
        if(errno != ENOENT) return -1;
    }

    /* update structure only if it succeeded */
    ev->events = events;
    return 0;
}



/* lwevent_set_*()
 *  Changes attributes associated with `ev'.
 */
void lwevent_set_callback(struct lwevent* ev, lwevent_callback callback)
{
    ev->callback = callback;
}

void lwevent_set_user(struct lwevent* ev, void* user)
{
    ev->user = user;
}
    
void lwevent_set_dtor(struct lwevent* ev, lwevent_dtor dtor)
{
    ev->dtor = dtor;
}

void lwevent_set_autodestroy(struct lwevent* ev, int autodestroy)
{
    ev->autodestroy = autodestroy;
}    



/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
vim: expandtab:ts=4:sw=4
*/
